``nota`` is an open-source application for organizing textual notes and
associated meta-information that may be used for later retrieval.  See
http://dankelley.github.io/nota for documentation on installing and using
``nota``.

**Version history**

* 0.8.11: default pager to 'none'.  (I was seeing problems in macos. Perhaps
  the arguments to 'less' have changed.)

* 0.8.10: add -p argument (for piping output of single notes)

* 0.8.9: only show hints if --hints arg is given

* 0.8.8: only mention trash if nothing in main

* 0.8.7: improve time formatting

* 0.8.6: remove string-decode bug (from python3 switch); try pypi description

* 0.8.1: switch from python2 to python3

* 0.8.0: attachments

* 0.7.9: aesthetic improvements

* 0.7.8: aesthetic improvements

* 0.7.7: --recent improved

* 0.7.6: --markdown improvements; --recent added

* 0.7.5: indicate ages in relative manner

* 0.7.4: fix bug in note age

* 0.7.3: improve note age format

* 0.7.2: do not store empty notes

* 0.7.1: add --pager argument (helps with long output)

* 0.7.0: notes may be organized into books

* 0.6.0: improve command arguments, esp. relating to searching and trash

* 0.5.x: first releases to https://pypi.python.org/pypi/nota
